Request class

Constructors

Request(int id, String method, dynamic params)

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
getter/setter pair
method ↔ String
getter/setter pair
params ↔ dynamic
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSONString() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited